setup_printer_struct

Attribute Macro setup_printer_struct 

#[setup_printer_struct]
Adds a new field with a fresh name to an existing struct type definition. The new field contains span information to be used with a printer. This macro will also derive implementations of hax_rust_engine::printer::pretty_ast::HasContextualSpan for the struct.