setup_error_handling_struct

Attribute Macro setup_error_handling_struct 

#[setup_error_handling_struct]
Adds a new field with a fresh name to an existing struct type definition. The new field contains error handling and span information to be used with a visitor. This macro will also derive implementations of hax_rust_engine::ast::visitors::wrappers::VisitorWithErrors and hax_rust_engine::ast::HasSpan for the struct.